@@ -1,23 +1,23 @@
 #' @title Function for organize data for Package SYNCSA
 #'
 #' @description Package \strong{SYNCSA} requires that the species and community sequence in
-#' the dataframe or matrix must be the same for all dataframe/matrices.
+#' the data.frame or matrix must be the same for all data.frame/matrices.
 #'
 #' @details The function organizes the data for the functions of the package
 #' SYNCSA, placing the matrices of community, traits, phylogenetic
 #' distance, environmental varibles and strata vector in the same order.
-#' The function use as reference the community data for organize all data frame or matrices
+#' The function use as reference the community data for organize all data.frame or matrices
 #' in the same order that the sampling units names and species names found in community
 #' data set. For this all data sets entered must be correctly named, with rows and columns
 #' named. The matrices phylodist, traits, envir can be larger than community
 #' data (more species and/or more sampling units) as long as it has at least
 #' all species and/or sampling units that are in community data. The function
-#' organizes the data despite the absence of one of the dataframes or matrices,
+#' organizes the data despite the absence of one of the data.frames or matrices,
 #' provided that the community data had been entered. Unspecified data will
 #' appear as NULL.
 #'
 #' When trait is a data.frame with differents types of variables correctly identified and
-#' convert.traits is TRUE factor traits are expanded in dummy traits and ordinal variables
+#' the argument convert.traits is TRUE factor traits are expanded in dummy traits and ordinal variables
 #' are converted in numeric according to ranks argument.
 #'
 #' The strata must be a named vector. The strata vector is a vector for restrict
@@ -27,7 +27,7 @@
 #' @encoding UTF-8
 #' @param comm Community data, with species as columns and sampling units as
 #' rows.
-#' @param traits Matrix or dataframe of species described by traits, with traits as
+#' @param traits Matrix or data.frame of species described by traits, with traits as
 #' columns and species as rows (Default traits = NULL).
 #' @param phylodist Matrix containing phylogenetic distance between species.
 #' Must be a complete matrix (not a half diagonal matrix).This matrix can be
@@ -46,13 +46,21 @@
 #' convert to ranks. If ranks = TRUE all ordered variable are replaced by their ranks
 #' and if ranks = FALSE all ordinal variables are simply treated as continuous variables
 #' (Default ranks = TRUE).
-#' @return The dataframes or matrices of community, traits, phylogenetic distance and
-#' environmental variables, as well as the type of each varible in each dataframe or matrix
-#' (where 'c' to continuous/numeric, 'o' to ordinal, 'b' to binary and 'f' to factor, nominal
-#' are not allowed). The strata vector for permutations. If convert.traits is TRUE and some
-#' traits is of class factor the function returm the traits with expand traits in dummy variables
-#' and return a list with sugestion to group of traits that are analysed together. Warning messenger
-#' are returned as a list of warning.
+#' @return A object of class metacommunity.data (also of the class list) with the data.frames or matrices:
+#' \item{call}{The arguments used.}
+#' \item{community}{Community data.}
+#' \item{traits}{Traits data.}
+#' \item{phylodist}{Phylogenetic distance.}
+#' \item{environmental}{Environmental variables.}
+#' \item{community.var.type}{Type of each varible in community data,
+#' where 'c' to continuous/numeric, 'o' to ordinal, 'b' to binary and 'f' to factor. Nominal are not allowed.}
+#' \item{traits.var.type}{Type of each varible in traits data. See labels above.}
+#' \item{phylodist.var.type}{Type of each varible in phylodist. See labels above.}
+#' \item{environmental.var.type}{Type of each varible in environmental data. See labels above.}
+#' \item{strata}{The strata vector for permutations.}
+#' \item{put.together}{A list with suggestion to group of traits that are analyzed together,
+#' only if convert.traits is TRUE and if some traits are of factor class.}
+#' \item{list.warning}{A list of warning.}
 #' @author Vanderlei Julio Debastiani <vanderleidebastiani@@yahoo.com.br>
 #' @seealso \code{\link{syncsa}}, \code{\link{var.dummy}}, \code{\link{var.type}}
 #' @keywords SYNCSA
@@ -64,10 +72,12 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
                              check.comm = TRUE, convert.traits = FALSE, ranks = TRUE)
 {
   res <- list(call = match.call())
+  res.temp <- res
+  res.temp$stop <- FALSE
   if (missing(comm)){
     stop("\n comm not fount\n")
   }
-  if(class(comm) != "data.frame" & class(comm) != "matrix"){
+  if(!inherits(comm, c("data.frame", "matrix"))){
     stop("comm must be a matrix or a data.frame")
   }
   if (is.null(colnames(comm))){
@@ -91,7 +101,7 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     }
     if(length(row.rm)>0){
       warning("Communities removed from community data - Check list of warning in list.warning", call. = FALSE)
-      list.warning$comm$comm <- data.frame(communities.removed=row.rm)
+      list.warning$comm$comm <- data.frame(communities.removed = row.rm)
     }
     comm <- comm[, colSums(comm, na.rm = TRUE)>0, drop = FALSE]
     comm <- comm[rowSums(comm,na.rm=TRUE)>0, , drop = FALSE]
@@ -100,7 +110,7 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     warning("Warning: NA in community data", call. = FALSE)
   }
   if (!is.null(traits)) {
-    if(class(traits) != "data.frame" & class(traits) != "matrix"){
+    if(!inherits(traits, c("data.frame", "matrix"))){
       stop("traits must be a matrix or a data.frame")
     }
     if (is.null(colnames(traits))){
@@ -117,7 +127,9 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     if(sum(is.na(match.names))>0){
       list.warning$traits$spp <- data.frame(species.not.on.traits = setdiff(colnames(comm), rownames(traits)))
       warning("ERROR - Check list of warning in list.warning$traits", call. = FALSE)
-      return(list(list.warning = list.warning))
+      res.temp$stop <- TRUE
+      res.temp$list.warning <- list.warning
+      return(res.temp)
     }
     traits <- as.data.frame(traits[match.names, , drop = FALSE])
     if(convert.traits){
@@ -148,7 +160,7 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     }
   }
   if (!is.null(phylodist)) {
-    if(class(phylodist) != "data.frame" & class(phylodist) != "matrix"){
+    if(!inherits(phylodist, c("data.frame", "matrix"))){
       stop("phylodist must be a matrix or a data.frame")
     }
     if (is.null(colnames(phylodist))){
@@ -165,7 +177,9 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     if(sum(is.na(match.names))>0){
       list.warning$phylodist$spp <- data.frame(species.not.on.phylodist = setdiff(colnames(comm), colnames(phylodist)))
       warning("ERROR - Check list of warning in list.warning$phylodist", call. = FALSE)
-      return(list.warning)
+      res.temp$stop <- TRUE
+      res.temp$list.warning <- list.warning
+      return(res.temp)
     }
     phylodist <- phylodist[match.names, match.names, drop = FALSE]
     if(any(is.na(phylodist))){
@@ -173,7 +187,7 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     }
   }
   if (!is.null(envir)) {
-    if(class(envir) != "data.frame" & class(envir) != "matrix"){
+    if(!inherits(envir, c("data.frame", "matrix"))){
       stop("envir must be a matrix or a data.frame")
     }
     if (is.null(colnames(envir))){
@@ -189,8 +203,10 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     match.names <- match(rownames(comm), rownames(envir))
     if(sum(is.na(match.names))>0){
       list.warning$envir$comm <- data.frame(comm.not.on.envir = setdiff(rownames(comm), rownames(envir)))
-      warning("ERROR - Check list of warning in list.warning$envir",call.=FALSE)
-      return(list.warning)
+      warning("ERROR - Check list of warning in list.warning$envir", call. = FALSE)
+      res.temp$stop <- TRUE
+      res.temp$list.warning <- list.warning
+      return(res.temp)
     }
     envir <- envir[match.names,,drop=FALSE]
     if(any(is.na(envir))){
@@ -204,8 +220,10 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
     match.names <- match(colnames(comm), names(strata))
     if(sum(is.na(match.names))>0){
       list.warning$strata <- data.frame(species.not.on.strata = setdiff(colnames(comm), names(strata)))
-      warning("ERROR - Check list of warning in list.warning$strata",call.=FALSE)
-      return(list.warning)
+      warning("ERROR - Check list of warning in list.warning$strata", call. = FALSE)
+      res.temp$stop <- TRUE
+      res.temp$list.warning <- list.warning
+      return(res.temp)
     }
     strata <- strata[match.names]
   }
@@ -237,5 +255,6 @@ organize.syncsa <- function (comm, traits = NULL, phylodist = NULL, envir = NULL
   res$environmental.var.type <- envirvartype
   res$strata <- strata
   res$put.together <- put.together
+  class(res) <- c("list", "metacommunity.data")
   return(res)
 }
