@@ -4,7 +4,7 @@
 #'
 #' @encoding UTF-8
 #' @param data A matrix.
-#' @param strata Argument to specify restricting permutations in rows (Default strata = NULL).
+#' @param strata Strata vector to specify restricting permutations in rows, must be the same length of number of rows in data matrix (Default strata = NULL).
 #' @param seqpermutation A set of predefined permutation vector (Default seqpermutation = NULL).
 #' @return \item{permut.matrix}{The matrix permuted.} \item{samp}{The sequence of permutation.}
 #' @author Vanderlei Julio Debastiani <vanderleidebastiani@@yahoo.com.br>
@@ -13,8 +13,8 @@
 #' @export
 permut.row.matrix <- function(data, strata = NULL, seqpermutation = NULL)
 {
-  N <- dim(data)[1]
-  if(!is.null(strata) & N!=length(seqpermutation)){
+  N <- nrow(data)
+  if(!is.null(strata) & N!=length(strata)){
     stop("\n strata must be the length of number of row in the data\n")
   }
   if(!is.null(seqpermutation) & N!=length(seqpermutation)){
